import importlib

from fastapi import APIRouter, Depends, Request
from starlette.templating import Jinja2Templates

from api import get_db
from model.settings import settings

router = APIRouter(
    prefix="/api"
)

templates = Jinja2Templates(directory='./templates')

registered_js_mods = settings.js_modules

for module_name in settings.loaded_modules:
    module = importlib.import_module('api.' + module_name)
    if hasattr(module, 'js_mods'):
        registered_js_mods += module.js_mods

registered_js_mods = set(registered_js_mods)


def convert_omdl(omdl):
    return {
        'is_devel': omdl.OP_ENV_IS_DEVEL,
        'is_prod': omdl.OP_ENV_IS_PROD,
        'is_test': omdl.OP_ENV_IS_TEST,
        'mode': omdl.OP_ENV_MODE,
    }


@router.get('/system/info')
async def get_sysinfo(db=Depends(get_db)):
    return {
        'version': settings.version,
        'version_name': settings.version_name,
        'mods': settings.loaded_modules,
        'host_oper_mode': convert_omdl(db.host_omdl),
        'js_mods': registered_js_mods,
        'netdb_admin_base': settings.netdb_admin_base
    }


@router.get('/opensearch.xml')
async def get_opensearch_xml(request: Request, db=Depends(get_db)):
    return templates.TemplateResponse('opensearch.xml', {
        'request': request,
        'netvs_url': request.base_url,
        'host_oper_mode': db.host_omdl
    }, media_type='application/opensearchdescription+xml')
